==> dde-shell_1.99.36.tar.xz: BUILD/panels/notification/center/translations/org.deepin.ds.notificationcenter_fi.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fi">
<context>
    <name>GroupNotify</name>
    <message>
        <source>Clear All</source>
        <translation>Tyhjennä kaikki</translation>
    </message>
</context>
<context>
    <name>NotifyHeader</name>
    <message>
        <source>Notification Center</source>
        <translation>Ilmoituskeskus</translation>
    </message>
    <message>
        <source>Clear All</source>
        <translation>Tyhjennä kaikki</translation>
    </message>
</context>
<context>
    <name>NotifySetting</name>
    <message>
        <source>Unpin</source>
        <translation>Irrota</translation>
    </message>
    <message>
        <source>Pin</source>
        <translation>Kiinnitä</translation>
    </message>
    <message>
        <source>Notification Setting</source>
        <translation>Ilmoitusten asetukset</translation>
    </message>
</context>
<context>
    <name>notifycenter::AppNotifyItem</name>
    <message>
        <source>Just now</source>
        <translation>Juuri nyt</translation>
    </message>
    <message>
        <source>%1 minutes ago</source>
        <translation>%1 min sitten</translation>
    </message>
    <message>
        <source>1 hour ago</source>
        <translation>1 h sitten</translation>
    </message>
    <message>
        <source>%1 hours ago</source>
        <translation>%1 h sitten</translation>
    </message>
    <message>
        <source>Yesterday </source>
        <translation>Eilen</translation>
    </message>
</context>
</TS>

==> dde-shell_2.0.3.tar.xz: BUILD/panels/notification/center/translations/org.deepin.ds.notificationcenter_fi.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="fi">
<context>
    <name>GroupNotify</name>
    <message>
        <source>Clear All</source>
        <translation>Tyhjennä kaikki</translation>
    </message>
</context>
<context>
    <name>NotifyHeader</name>
    <message>
        <source>Notification Center</source>
        <translation>Ilmoituskeskus</translation>
    </message>
    <message>
        <source>Clear All</source>
        <translation>Tyhjennä kaikki</translation>
    </message>
</context>
<context>
    <name>NotifySetting</name>
    <message>
        <source>Unpin</source>
        <translation>Irrota</translation>
    </message>
    <message>
        <source>Pin</source>
        <translation>Kiinnitä</translation>
    </message>
    <message>
        <source>Notification Setting</source>
        <translation>Ilmoitusten asetukset</translation>
    </message>
</context>
<context>
    <name>notifycenter::AppNotifyItem</name>
    <message>
        <source>Just now</source>
        <translation>Juuri nyt</translation>
    </message>
    <message>
        <source>%1 minutes ago</source>
        <translation>%1 min sitten</translation>
    </message>
    <message>
        <source>1 hour ago</source>
        <translation>1 h sitten</translation>
    </message>
    <message>
        <source>%1 hours ago</source>
        <translation>%1 h sitten</translation>
    </message>
    <message>
        <source>Yesterday </source>
        <translation>Eilen</translation>
    </message>
</context>
</TS>
